#
# spec file for package gssntlmssp
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gssntlmssp
Version:        0.8.0
Release:        bp153.1.21
Summary:        GSSAPI NTLMSSP Mechanism
License:        LGPL-3.0-or-later
Group:          Development/Languages/C and C++
URL:            https://pagure.io/gssntlmssp
Source:         https://pagure.io/gssntlmssp/archive/v%{version}/%{name}-v%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  doxygen
BuildRequires:  gettext-devel
BuildRequires:  libtool
BuildRequires:  libunistring-devel
BuildRequires:  libxml2-tools
BuildRequires:  libxslt-tools
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig
BuildRequires:  sgml-skel
BuildRequires:  pkgconfig(krb5-gssapi) >= 1.11.2
BuildRequires:  pkgconfig(wbclient)
BuildRequires:  pkgconfig(zlib)
Requires:       krb5 >= 1.11.2

%description
A GSSAPI Mechanism that implements NTLMSSP.

%package devel
Summary:        Development header for GSSAPI NTLMSSP
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
A header file with definitions for custom GSSAPI extensions for NTLMSSP.

%prep
%setup -q -n %{name}-v%{version}

%build
autoreconf -fiv
%configure \
    --with-wbclient \
    --disable-static \
    --disable-rpath

%make_build all

%install
%make_install
rm -f %{buildroot}%{_libdir}/gssntlmssp/gssntlmssp.la
rm -rf %{buildroot}%{_datadir}/doc/gssntlmssp/
install -D -p -m0644 examples/mech.ntlmssp %{buildroot}%{_sysconfdir}/gss/mech.d/ntlmssp.conf
%find_lang %{name}

%check
%make_build test_gssntlmssp

%files -f %{name}.lang
%license COPYING
%doc README.md doc/compatibility.md
%{_sysconfdir}/gss/
%config(noreplace) %{_sysconfdir}/gss/mech.d/ntlmssp.conf
%{_libdir}/gssntlmssp/
%{_mandir}/man8/gssntlmssp.8%{?ext_man}

%files devel
%{_includedir}/gssapi/gssapi_ntlmssp.h

%changelog
* Thu Feb 27 2020 Martin Hauke <mardnh@gmx.de>
- Specfile cleanup
* Wed Aug 14 2019 Simona Avornicesei <simona@avornicesei.com>
- Fixed build on Fedora / CentOS
* Wed Aug 14 2019 Simona Avornicesei <simona@avornicesei.com>
- Fixed build on OpenSUSE Tumbleweed
* Tue Apr 23 2019 Simona Avornicesei <simona@avornicesei.com>
- build GSSNTLMSSP package v0.8.0 from https://pagure.io/gssntlmssp
* Thu Apr 18 2019 Simo Sorce <simo@redhat.com>
- New upstream release 0.8.0:
  * Add compatibility with OpenSSL 1.1.0
  * Port some documentation into the tree
  * Rename and split the README file
  * Add support for RFC5801
  * Add support to return SSF value
* Fri Jun  3 2016 Simo Sorce <simo@samba.org>
- New upstream release 0.7.0:
  * Return the actual_mech_type when requested
  * Add test to check actual_mech is actually returned
  * Fix gss_inquire_cred with no creds
  * Return actual mech on accept context too
  * Add test for accept returning mech
  * Add placeholder inquire_name
  * Fix a regression in error handling
  * Check that we are actually asking for a known oid
  * Move setting seq numbers to a spearate function
  * Add context extension to reset crypto state
* Mon Feb 23 2015 Simo Sorce <simo@samba.org>
- Update EPEL to latest version
* Sun Jan 26 2014 Simo Sorce <simo@samba.org>
- Fixes #1058025
- New upstream release 0.3.1:
  * Fix segfault in init context.
* Sun Jan 12 2014 Simo Sorce <simo@samba.org>
- New upstream release 0.3.0:
  * Added support for NTLMv1 Signing and Sealing completing full coverage
    of the NTLM protocol
  * Added a number of GSSAPI calls to inquire, export and import context and
    credentials, in preparation for making it work with GSS-Proxy
  * Various fixes memleak and other fixes
* Wed Dec  4 2013 Simo Sorce <simo@samba.org>
- Backport patch that fixes failures with gss_set_neg_mechs() calls.
* Fri Oct 18 2013 Simo Sorce <simo@samba.org>
- New upstream realease 0.2.0:
  * Add support for acquire_cred_with_password()
  * Fix Signing keys generation
  * Add enterprise names support
  * Add connectionless mode support
  * Add development header gssapi_ntlmssp.h
  * Various bugfixes and tests for new features
* Thu Oct 17 2013 Simo Sorce <simo@samba.org>
- Initial import of 0.1.0
